@@ -1,5 +1,5 @@
 "permutest.cca" <-
-function (x, permutations = 100, model = c("reduced", "full")) 
+function (x, permutations = 100, model = c("reduced", "full"), strata) 
 {
     model <- match.arg(model)
     Chi.z <- x$CCA$tot.chi
@@ -18,21 +18,22 @@ function (x, permutations = 100, model = c("reduced", "full"))
     N <- nrow(E)
     Q <- x$CCA$QR
     for (i in 1:permutations) {
-        take <- sample(N, N)
-        #take <- canoperm[i,]
+        take <- permuted.index(N, strata)
         Y <- E[take, ]
         if (!is.null(x$pCCA)) {
             Y <- Y.Z + Y
             Y <- qr.resid(QZ, Y)
         }
-        #cca.ev <- sum(svd(qr.fitted(Q, Y), nv = 0, nu = 0)$d[1:q]^2)
-        #ca.ev <- sum(svd(qr.resid(Q, Y), nv = 0, nu = 0)$d[1:r]^2)
-        cca.ev <- sum(diag(crossprod(qr.fitted(Q,Y))))
-        ca.ev <- sum(diag(crossprod(qr.resid(Q,Y))))
+        cca.ev <- sum(diag(crossprod(qr.fitted(Q, Y))))
+        ca.ev <- sum(diag(crossprod(qr.resid(Q, Y))))
         F.perm[i] <- (cca.ev/q)/(ca.ev/r)
     }
     sol <- list(Call = x$Call, model = model, F.0 = F.0, F.perm = F.perm, 
         nperm = permutations)
+    if(!missing(strata)) {
+        sol$strata <- deparse(substitute(strata)) 
+        sol$stratum.values <- strata
+    }
     class(sol) <- "permutest.cca"
     sol
 }
