@@ -1,7 +1,7 @@
 "print.permutest.cca" <-
-function (x, ...) 
+    function (x, ...) 
 {
-    cat("\nPermutation test for CCA call:\n")
+    cat("\nPermutation test for a CCA/RDA call:\n")
     cat(deparse(x$Call), "\n\n")
     Pval <- sum(x$F.perm >= x$F.0)/x$nperm
     cat("Test for significance of all constrained eigenvalues\n")
@@ -9,8 +9,8 @@ function (x, ...)
     cat("Significance:\t", format.pval(Pval, eps = 1/x$nperm), 
         "\n")
     cat("Based on", x$nperm, "permutations under", x$model, "model")
-    if (!is.null(x$strata))
-       cat(",\nstratified within factor", x$strata)
+    if (!is.null(x$strata)) 
+        cat(",\nstratified within factor", x$strata)
     cat(".\n\n")
     invisible(x)
 }
